
Isource
=======


.. automodule:: opendssdirect.Isource
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Isource.AllNames

    Names of all Isources in the circuit.

.. function:: opendssdirect.Isource.Amps

    Get the magnitude of the Isource in Amps.Set the magnitude of the Isource in Amps.

.. function:: opendssdirect.Isource.AngleDeg

    Get the phase angle of the Isource in degrees.Set the phase angle of the Isource in degrees.

.. function:: opendssdirect.Isource.Count

    Returns the number of Isource objects currently defined in the active circuit.

.. function:: opendssdirect.Isource.First

    Set the first ISource to be active; returns 0 if none.

.. function:: opendssdirect.Isource.Frequency

    Get the frequency of the Isource in Hz.Set the frequency of the Isource in Hz.

.. function:: opendssdirect.Isource.Name

    Get the name of the active Isource object.Set the name of the active Isource object.

.. function:: opendssdirect.Isource.Next

    Set the next ISource to be active; returns 0 if none.

